@@ -16,10 +16,20 @@
 #define LAGER_HAS_CPP17 1
 #endif
 
-#ifdef __has_feature
-#if !__has_feature(cxx_exceptions)
+#if defined(_MSC_VER) && !defined(LAGER_DISABLE_STORE_DEPENDENCY_CHECKS)
+#define LAGER_DISABLE_STORE_DEPENDENCY_CHECKS
+#endif
+
+#if !defined(LAGER_USE_EXCEPTIONS) && !defined(LAGER_NO_EXCEPTIONS)
+#if defined(_MSC_VER)
+#if !_HAS_EXCEPTIONS
 #define LAGER_NO_EXCEPTIONS
 #endif
+#else
+#if !__cpp_exceptions
+#define LAGER_NO_EXCEPTIONS
+#endif
+#endif
 #endif
 
 #ifdef LAGER_NO_EXCEPTIONS
@@ -37,4 +47,3 @@
 #define LAGER_THROW(expr) throw expr
 #define LAGER_RETHROW throw
 #endif
-
